# Generated by roxygen2: do not edit by hand

export(.add_utility)
export(.check_uniqueness)
export(.gen_colours)
export(.get_lfs)
export(.get_names)
export(.getmode)
export(.modify_ggplot_theme)
export(.pchc)
export(.pchc_plot_by_dim)
export(.pchctab)
export(.prep_eq5d)
export(.prep_fu)
export(.prep_vas)
export(.summary_cts_by_fu)
export(.summary_mean_ci)
export(.summary_table_2_1)
export(.summary_table_4_3)
export(.summary_table_4_4)
export(eq5d)
export(eq5d3l)
export(eq5d5l)
export(eq5d_profile_better_dimensions_by_group_plot)
export(eq5d_profile_change_summary)
export(eq5d_profile_density_curve)
export(eq5d_profile_dimension_change_table)
export(eq5d_profile_health_profile_grid)
export(eq5d_profile_level_summary)
export(eq5d_profile_level_summary_by_group)
export(eq5d_profile_lfs_distribution)
export(eq5d_profile_lfs_mean_utility)
export(eq5d_profile_lfs_utility_plot)
export(eq5d_profile_lfs_utility_summary)
export(eq5d_profile_lss_utility_plot)
export(eq5d_profile_lss_utility_summary)
export(eq5d_profile_mixed_dimensions_by_group_plot)
export(eq5d_profile_pchc_by_group_plot)
export(eq5d_profile_pchc_table)
export(eq5d_profile_pchc_with_no_problems_table)
export(eq5d_profile_top_states)
export(eq5d_profile_worse_dimensions_by_group_plot)
export(eq5d_utility_by_group_plot)
export(eq5d_utility_change_by_group_plot)
export(eq5d_utility_distribution_plot)
export(eq5d_utility_norms_comparison)
export(eq5d_utility_over_time_plot)
export(eq5d_utility_summary)
export(eq5d_utility_summary_by_group)
export(eq5d_utility_vas_scatter_plot)
export(eq5d_vas_distribution_table)
export(eq5d_vas_grouped_distribution_plot)
export(eq5d_vas_histogram)
export(eq5d_vas_summary)
export(eq5dy3l)
export(eqvs_add)
export(eqvs_display)
export(eqvs_drop)
export(eqvs_load)
export(eqxw)
export(eqxw_UK)
export(eqxwr)
export(make_all_EQ_indexes)
export(make_all_EQ_states)
export(make_dummies)
export(run_app)
export(toEQ5Ddims)
export(toEQ5Dindex)
export(update_value_sets)
import(RColorBrewer)
import(ggplot2)
import(moments)
import(scales)
importFrom(grDevices,colorRampPalette)
importFrom(moments,kurtosis)
importFrom(rlang,.data)
importFrom(stats,aggregate)
importFrom(stats,dnorm)
importFrom(stats,median)
importFrom(stats,quantile)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(stats,weighted.mean)
importFrom(utils,head)
importFrom(utils,read.csv)
