% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/migrations.R
\name{get_applied_migrations}
\alias{get_applied_migrations}
\title{Get the list of already-applied migrations}
\usage{
get_applied_migrations()
}
\value{
A character vector of migration IDs.
}
\description{
Reads the locally cached list of migration IDs that have
already been applied. Returns an empty character vector if
no migrations have been applied yet.
}
\keyword{internal}
