% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/eq5d_devlin.R
\name{eq5d_vas_histogram}
\alias{eq5d_vas_histogram}
\title{eq5d_vas_histogram: EQ VAS scores}
\usage{
eq5d_vas_histogram(df, name_vas = NULL)
}
\arguments{
\item{df}{Data frame with the VAS column}

\item{name_vas}{Character string for the VAS column}
}
\value{
Summary plot and data used for plotting
}
\description{
eq5d_vas_histogram: EQ VAS scores
}
\examples{
tmp <- eq5d_vas_histogram(example_data, name_vas = 'vas')
tmp$p
tmp$plot_data
}
